@@ -304,10 +304,12 @@ as_lag <- function(x, ...) {
   UseMethod("as_lag")
 }
 
+#' @export
 as_lag.interval <- function(x, ...){
   new_lag(1, x)
 }
 
+#' @export
 as_lag.default <- function(x, ...){
   abort(
     sprintf("`as_lag()` doesn't know how to handle the '%s' class yet.",
@@ -387,6 +389,12 @@ interval_pull.cf_lag <- function(x) {
 }
 
 #' Auto- and Cross- Covariance and -Correlation plots
+#' 
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `autoplot.tbl_cf()` was soft deprecated in feasts 0.4.2. Please use
+#' `ggtime::autoplot.tbl_cf()` instead. Produces a plot of impulse responses
+#' from an impulse response function.
 #'
 #' Produces an appropriate plot for the result of  [`ACF()`], [`PACF()`], or [`CCF()`].
 #'
@@ -401,7 +409,10 @@ interval_pull.cf_lag <- function(x) {
 #' @export
 autoplot.tbl_cf <- function(object, level = 95, ...){
   cf_type <- colnames(object)[colnames(object) %in% c("acf", "pacf", "ccf")]
-  plot_aes <- eval_tidy(expr(ggplot2::aes(x = !!sym("lag"), y = !!sym(cf_type))))
+  plot_aes <- ggplot2::aes(
+    x = !!sym("lag"),
+    y = !!sym(cf_type)
+  )
   interval <- interval(object)
 
   if(length(level) > 1){
@@ -410,7 +421,7 @@ autoplot.tbl_cf <- function(object, level = 95, ...){
 
   itvl_fmt <- utils::getS3method("format", "interval", envir = getNamespace("tsibble"))
   p <- ggplot(object, plot_aes) +
-    geom_linecol() +
+    ggplot2::geom_segment(aes(xend = !!sym("lag"), yend = 0)) +
     geom_hline(yintercept = 0) +
     xlab(paste0("lag [", itvl_fmt(interval),"]"))
 
