@@ -28,7 +28,7 @@
 #'
 #' @export
 guerrero <- function(x, lower = -0.9, upper = 2, .period = 2L) {
-  if(all(x == x[1])) return(1)
+  if(all(x == x[1])) return(c(lambda_guerrero = 1))
 
   # Prepare seasonal subseries
   .period <- max(2L, .period)
